<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>Закрепить сверху</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>Удалить с рабочего стола</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Отправить на рабочий стол</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Удалить из дока</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Отправить в док</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Удалить из автозагрузки</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Добавить в автозагрузку</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Использовать прокси</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Отключить маштабирование экрана</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>Полноэкранный режим</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>Установить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>Часто используемое</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>Оконный режим</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Игры</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Вы уверены, что хотите удалить &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>Недавно установленные</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>Все приложения</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Ничего не найдено</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>Свободная сортировка</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>Сортировать по категориям</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>Сортировать по имени</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>Вид сортировки</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Картинки</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Рабочий Стол</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>Центр управления</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>Интернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графика</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Игры</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офис</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Разработка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>Лаунчпад</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Вы уверены, что хотите удалить &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
</TS>